pub struct BinnedQualityCodec;Expand description
Illumina-style 8-level quality score binning.
This is an explicitly lossy encoding that maps Phred quality scores into 8 bins, reducing entropy for better downstream compression while preserving the most important quality distinctions.
Bin boundaries and representative values:
Phred 0-1 → 0
Phred 2-9 → 6
Phred 10-19 → 15
Phred 20-24 → 22
Phred 25-29 → 27
Phred 30-34 → 33
Phred 35-39 → 37
Phred 40+ → 40Quality bytes are assumed to be Phred+33 encoded (standard Sanger/Illumina 1.8+ encoding). The binned output is also Phred+33 encoded.