pub struct SelectedRecord<'a, R, S = RawAsciiCodec, Q = RawQualityCodec, N = RawNameCodec, K = NoRecordKey, F = ReadAllFields> { /* private fields */ }Expand description
Borrowed current-record view returned by a selected reader.
The methods available on this view are determined by the selected field set used to build the reader. If a field was not selected, no accessor for that field is available on the type.
Implementations
Sourceimpl<R, S, Q, N, K, F> SelectedRecord<'_, R, S, Q, N, K, F>
impl<R, S, Q, N, K, F> SelectedRecord<'_, R, S, Q, N, K, F>
Sourceimpl<R, S, Q, N, K, F> SelectedRecord<'_, R, S, Q, N, K, F>
impl<R, S, Q, N, K, F> SelectedRecord<'_, R, S, Q, N, K, F>
Sourceimpl<R, S, Q, N, K, F> SelectedRecord<'_, R, S, Q, N, K, F>
impl<R, S, Q, N, K, F> SelectedRecord<'_, R, S, Q, N, K, F>
Sourceimpl<R, S, Q, N, K, F> SelectedRecord<'_, R, S, Q, N, K, F>where
R: Read,
S: SequenceCodec,
Q: QualityCodec,
N: NameCodec,
K: RecordKey,
F: SelectionExpr + HasKey,
impl<R, S, Q, N, K, F> SelectedRecord<'_, R, S, Q, N, K, F>where
R: Read,
S: SequenceCodec,
Q: QualityCodec,
N: NameCodec,
K: RecordKey,
F: SelectionExpr + HasKey,
Sourcepub fn record_key(&self) -> Result<K, DryIceError>
pub fn record_key(&self) -> Result<K, DryIceError>
Decode the selected record key.
Errors
Returns an error if the current block does not contain keys of type K
or if the key bytes cannot be decoded into K.